@@ -210,7 +210,7 @@ for(var in c('GFE', 'AI_mod', 'DBE')){
 
 #### Plot - Class comp bar####
 
-class_colors <- brewer.pal(9, name = 'Set3')
+class_colors <- brewer.pal(length(classification$Class) + 1, name = 'Set3')
 names(class_colors) <- c(classification$Class, 'Other')
 
 class_bar <- class_comp %>% 
